# Changelogs

## Latest Changes

## 0.0.1

### :sparkles: Features

- :dart: feat: add pre-commit and more feat for pocker game. (_2024-03-21_)

### :black_nib: Code Changes

- :construction: refactored: change file name and rename cli in pyproject. (_2024-05-05_)
- :construction: refactored: remove failed files and deps that does not important. (_2024-05-05_)
- :dart: initial: initial code for create poker card game (_2024-02-06_)
- :construction: refactored: Initial commit (_2024-02-04_)

### :bug: Fix Bugs

- :gear: fixed: merge branch 'main' of https://github.com/korawica/justcard into main. (_2024-03-21_)
- :gear: fixed: prepare skip repo id name on ci pre-commit. (_2024-03-21_)
- :gear: fixed: remove .idea folder on remote repo (_2024-03-21_)
- :gear: fixed: remove .idea folder on remote repo. (_2024-03-21_)

### :package: Build & Workflow

- :toolbox: build: add gihub workflow for test and publish. (_2024-05-04_)
